==> webkit-1.8.0.tar.xz: webkit-1.8.0/Source/WebCore/svg/SVGVKernElement.h <==
/*
 * Copyright (C) Research In Motion Limited 2010. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef SVGVKernElement_h
#define SVGVKernElement_h

#if ENABLE(SVG_FONTS)
#include "SVGFontElement.h"
#include "SVGParserUtilities.h"
#include "SVGStyledElement.h"

#include <limits>
#include <wtf/Forward.h>

namespace WebCore {

class SVGVKernElement : public SVGElement {
public:
    static PassRefPtr<SVGVKernElement> create(const QualifiedName&, Document*);

    void buildVerticalKerningPair(KerningPairVector&);

private:
    SVGVKernElement(const QualifiedName&, Document*);

    virtual void insertedIntoDocument();
    virtual void removedFromDocument();

    virtual bool rendererIsNeeded(const NodeRenderingContext&) { return false; }
};

} // namespace WebCore

#endif // ENABLE(SVG_FONTS)
#endif

==> webkit_1.9.2.orig.tar.xz: webkit-1.9.2/Source/WebCore/svg/SVGVKernElement.h <==
/*
 * Copyright (C) Research In Motion Limited 2010. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef SVGVKernElement_h
#define SVGVKernElement_h

#if ENABLE(SVG_FONTS)
#include "SVGFontElement.h"
#include "SVGParserUtilities.h"
#include "SVGStyledElement.h"

#include <limits>
#include <wtf/Forward.h>

namespace WebCore {

class SVGVKernElement : public SVGElement {
public:
    static PassRefPtr<SVGVKernElement> create(const QualifiedName&, Document*);

    void buildVerticalKerningPair(KerningPairVector&);

private:
    SVGVKernElement(const QualifiedName&, Document*);

    virtual InsertionNotificationRequest insertedInto(Node*) OVERRIDE;
    virtual void removedFrom(Node*) OVERRIDE;

    virtual bool rendererIsNeeded(const NodeRenderingContext&) { return false; }
};

} // namespace WebCore

#endif // ENABLE(SVG_FONTS)
#endif
